#
# spec file for package rofi-wayland
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rofi-wayland
Version:        1.7.8+wayland1+git.1737536808.03a3a58
Release:        1.2
Summary:        A window switcher, run dialog and dmenu replacement
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/lbonn/rofi
Source:         rofi-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  check-devel
BuildRequires:  flex >= 2.5.39
BuildRequires:  gcc-c++
BuildRequires:  gtk-layer-shell-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  librsvg-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  meson
BuildRequires:  pandoc
BuildRequires:  pango-devel
BuildRequires:  pkgconfig
BuildRequires:  startup-notification-devel
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)
Conflicts:      rofi
Provides:       rofi-launcher

%description
This is a fork of rofi with added support for Wayland via the layer shell protocol.

%package devel
Summary:        Development files for rofi
Group:          Development/Libraries/C and C++
Conflicts:      rofi-devel

%description devel
Development files and headers for rofi

%prep
%autosetup -p1 -n rofi-%{version}

sed -i '1s,%{_bindir}/env bash,/bin/bash,' script/rofi-sensible-terminal \
    script/rofi-theme-selector

%build
%meson -Dxcb=disabled
%meson_build

%install
%meson_install

%files
%license COPYING
%doc Changelog README.md
%{_bindir}/rofi
%{_bindir}/rofi-sensible-terminal
%{_bindir}/rofi-theme-selector
%dir %{_datadir}/rofi/
%{_datadir}/rofi/themes/
%{_datadir}/applications/rofi*
%{_datadir}/icons/hicolor/scalable/apps/rofi.svg
%{_mandir}/man1/rofi.1%{?ext_man}
%{_mandir}/man1/rofi-sensible-terminal.1%{?ext_man}
%{_mandir}/man1/rofi-theme-selector.1%{?ext_man}
%{_mandir}/man5/rofi-debugging.5%{?ext_man}
%{_mandir}/man5/rofi-dmenu.5%{?ext_man}
%{_mandir}/man5/rofi-keys.5%{?ext_man}
%{_mandir}/man5/rofi-script.5%{?ext_man}
%{_mandir}/man5/rofi-theme.5%{?ext_man}
%{_mandir}/man5/rofi-thumbnails.5%{?ext_man}

%files devel
%{_includedir}/rofi/
%{_libdir}/pkgconfig/rofi.pc

%changelog
* Sat Feb  1 2025 smolsheep@opensuse.org
- Update to version 1.7.8+wayland1+git.1737536808.03a3a58:
  * Fix buffer overflow in rofi -e after reading from stdin
  * [DRun] Reduce DBus timeout to 1500ms add option to disable
    DBusActivatable.
* Tue Jan  7 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.7.7+wayland1+git.1736252691.5df2d3a:
  * Sync to rofi 1.7.7
  Fixes
  * clipboard pasting done properly on wayland
  * keyboard input on Plasma and niri.
  * imdkit build detection
  Features
  * touchpad scrolling
- Updates from rofi 1.7.7:
  * [Widget] Don't use cairo_push/pop_group as it causes issues.
  * Revert "[window] Check bitmask, not full comparison".
  * [Config] Remove character data type as it aliases with string.
  * [Doc] Refer to releasenotes for updates in Changelog file.
  * [Doc] Update theme documentation with import resolving update.
  * [Themes] Update themes to import without rasi(nc) extensions.
  * [Theme] Fix resolving of 'rasinc' extension when no extension
    is given.
  * Be more diligent trying to resolve -config.
  * Resolve -config argument identical to a -theme argument.
  * [DRun] If indicated by .desktop file, launch via dbus
    activation.
  * [Website] Update website links and headers.
- Updates from rofi 1.7.6:
  * [DOC] Add mouse button names to documentation.
  * [Doc] Clarify documentation for User Script directory.
  * [Build] Add shadow to build system.
  * [Textbox] Use FontMetrics font height (if available) to get
    height
  * [Theme] Fixes recursion in double_inside
  * [autoconf] Fix missing dependency.
  * Better XIM interaction by filtering modifiers
  * Fix ime and enable build option
  * [Autotools] Ship missing files for meson build
  * Fix some compiler warnings
  * Disable history in password mode, move disabling into
    create_view.
  * [config] Set filebrowser as default completer.
  * [WIP] xdg thumbnails fetching with fallback on mimetype icons
  * Add -transient-window mode
  * Fix scrolling for vertical layout with horizontal packing
  * Place continuous scroll center in middle column
  * [Script] Fix keep-selection add keep-filter
  * [RecursiveBrowser] Make implementation not recursive.
  * [xcb] Add border_width to window coordinates
  * [IconFetcher] Don't check for extension for image file
  * [IconFetcher] Fix failing decode of animated GIFs.
  * [Doc] Fix typos
  * [Run] Don't re-quote history items.
  * [Modes] Remove dead code in mode implems
  * [View] Work around GThreadPool 1 pointer bug.
  * Also fix typo in icon fetcher.
  * [Doc] Switch to pandoc and remove generated files
  * [Build] Add missing dist files from libnkutils
  * [IconFetcher] Don't free on removal from thread-pool
  * Add an item-free method to the thread-pool
  * [Window] write code so clang-check does not complain about
    leak.
  * [script|dmenu] Add option to make row permanent.
  * [run] fix missing doxygen and add explanation.
  * [Run] When passing raw entry, pass it unquoted to history
  * Replace deprecated g_memdup by g_memdup2
  * Fix compiler warnings in window mode.
  * Fix some compiler warnings.
  * [RUN] shell escape command before processing it further.
  * [DRun] Drun read url field from cache.
  * [Build] Reduce amount of warnings
  * [View] Don't use xcb surface to render to png, but create
    surface.
  * [Box] When estimating height, set correct width on children
  * [ThreadPool] Sort items in the queue based on priority
  * [Doc] Fix broken ``` guards.
  * [Doc] Remove reddit link from config.yml.
  * [Doc] Clarify in build instructions what release to use.
  * Add extra documentation issue template.
  * Fix typo in dynamic_themes.md
  * [DOC] Add explanation to PATTERN of brackets
  * [Doc] Update manpage to clarify meta property.
  * [View] On mode switch force refilter instead of queuing.
  * [View] Allow float delay
  * [View] Always forward motion to the grabbed widget first.
  * [IconFetcher] If last step fails to load icon, don't error out
    make warning
  * [Script] Update theme property clarification a bit.
  * [Script] Add clarification to theme property.
  * [Dmenu][Script] Add 'display' row option to override whats
    displayed.
  * [DRun] Allow url field to be searched and fix c/p error
  * [DRUN] Add {url} to drun-display-format.
  * [lexer] Add dmenu as enabled option for media type.
  * [XCB] Make sure that window maker is 0 terminated before usage.
  * Fix text color when cursor-color is set
  * [XCB] Try to be smarter with where mouse click started.
  * [View|Textbox] cleanups to drawing code
  * Clip text with extents rectangle Fonts are not ideal, some
    characters have mismatch between reported and painted size.
  * [Rofi] Expand cache-dir
  * Fix typos in dmenu docs
  * Support single quotes for strings as in CSS
  * [Theme] Fix missing doxygen documentation
  * [Theme] Fix opening abs path if no/wrong extension (backward
    comp.)
  * [rofi-theme] fix typo
  * [Theme] Try to fix importing of theme.
  * script: Let script handle empty custom input
  * widget_draw: clean useless calls in corner drawing
  * Fix border segments stitch
  * Fix mm type in description
  * Remaining modi words in the code
  * Better descriptions for sort options group
  * It's unobvious from documentation, that sort only works against
    filtered menu.
  * update man pages without scripts
  * [Lexer] Print some more debug info on error.
  * [Script] Set type on Mode object.
  * [window] Quick test of code scanning.
  * [ROFI] -e '-' reads from stdin
  * [ConfigParser] Don't pass commandline options with very long
    args. This is a quick 'n dirty fix for this unexpected issue.
  * [Build] Fix autotools build system.
  * [Doc] Fix some missing/wrong doxygen headers.
  * Print window manager in -help output
  * Merging in the Recursive file browser.
  * Add wezterm to rofi-sensible-terminal
  * [DRun] Add option to scan desktop directory for desktop files.
  * [IconFetcher] Fix small memory leak.
  * Small memory leaks fixed and other cleanups.
  * [DMenu] Fix row initial tab if non-first column is shown first.
  * [Doc] Update theme manpage with remark-lint hints.
  * [Doc] More small markdown fixes.
  * [DOC] Update rofi-script update with remark-lint remarks.
  * Remove unneeded test and extra enforcement of 0 terminated
    buffer
  * [Doc] Update rofi.1.markdown with markdown fixes.
  * [DOC] update readme.md with remark-lint updates..
  * [DOC] Update INSTALL,md with remark-lint fixes.
  * [DOC] Add some remark markdown fixes.
  * Fix to pointless or's.
  * [UnitTest] Add more tests for environment parsing.
  * [Doc] Mention location of scripts in manpage.
  * Re-indent the code using clang-format
  * Fix typo in template.
  * Update issue template to include checkbox for version.
  * [Doc] Re-generate manpage
  * docs: element children theming
  * Add support for adding textbox widgets to listview elements
  * [Textbox] cairo_save/restore does not store path. Fix by moving
    cairo_move_to to after blink. Also fix drawing outline.
  * More Unicode normalization with -normalize-match. Normalize the
    string to a fully decomposed form, then filter out mark/accent
    characters.
  * Calc broken fix
  * [Dmenu] Small fix that disabled async mode when multi-select is
    enabled.
  * [View] Fix wrong bitmask checking. (& not |)
  * [rofi-theme-selector] prepend newline before specifying new
    theme
  * [Script] Strip pango markup when matching rows
  * [Doc] theme, spelling fix and more textual tweaks.
  * [Doc] More tweaks to get the formulation right.
  * [Doc] themes manpage, small textual improvement.
  * [Doc] Try to fix some markdown, themes.
  * [Doc] Try to clarify the children situation for the listview
    widget.
  * [EntryHistory] Disable entry history when dmenu password is
    set.
  * [Textbox] Add history to the entrybox.
  * [Textbox] Add comments and move into sub functions.
  * [doc] Add conflicting constraint section to manpage.
  * [Script] Some small memory leak fixes.
  * [Entry History] Add documentation.
  * [doc] Add conflicting constraint section to manpage.
  * [Textbox] Replace 'space' with a space
  * draw text after cursor
  * [Doc] Small tweak to markdown.
  * [Example] Small change in escaping for caday.
  * [Doc] Add manpage documentation for pango font string.
  * [FileBrowser] Allow command to be overwritten
  * [theme] Small theme tweak.
  * [Theme] Add NO_IMAGE mode to theme.
  * [Themes] add fullscreen theme with preview part.
  * [window] When no window title set, handle this more gracefully
  * [DMenu|Script] Add per row urgent/active option. Instead of
    having a global list of entries to highlight urgent/active, you
    can now to it per row.
  * sed & realpath workaround for BSD and Darwin OS
  * [filebrowser] Add option to return 1 on cancel.
  * [Theme] Small tweak to fancy2 theme
  * [Themes] Add fancy2 theme.
  * [Themes] Add material theme
  * Fix header theme
  * [Helper] Quick fix for wrong dereference.
  * Add shipped themes page
  * [actions] Also rebuild website on the next branch
  * [themes] don't use screenshot transparency in shipped themes
  * [IconFetcher] Fix for api change
  * [Theme] support rasinc for theme include files.
  * [listview] Don't calculate infinite rows on empty height.
  * [Theme] Move some definitions header around for plugin.
  * [Textbox] Cursor goes over, not under. allow cursor outline.
  * [Textbox] Add text-outline to style
  * [Doc] Clarify documentation on require-input further.
  * make cursor more customizable by adding cursor-width and
    cursor-color
  * [XIM] Fix an unitialized value problem.
  * [Doc] Add example run command with cgroup support
  * [Build] Fix test building in makefile.
  * [Doc] Add documentation for new functions.
  * [Doc] Fix some missing docu.
  * [DMenu] Add -ellipsize-mode option.
  * [listview] Set ellipsize mode on creation of textbox
  * So if rows are added, they behave correctily.
  * Disable imdkit by default
  * Build documentation
  * [Build] Use built-in lto option.
  * [Window] Fix reloading windowcd from xserver request
  * [Build] Add option to build with lto to meson. Fix error in
    test.
  * [Build] Add option to disable imdkit at compile time.
  * input method
  * [Window] Make sure their is a trailing 0 on the workspace
    strings.
  * [FileBrowser] Bind kb-delete-entry to toggle show-hidden.
  * [Textbox] Add a 'get_cursor_x_pos' function.
  * [man] re-gen manpage.
  * [DOC] Add parsing row options to dmenu manpage
  * [Build] Fix icon install path for makefile.
  * [Window] Small fixes to prefer-icon-theme option
  * [Window] Add -window-prefer-icon-theme option.
  * [drun] Only pass path on launch, if one is set
  * The mode is filebrowser (not file-browser)
  * [filebrowser] Add an option to show hidden files.
  * [Doc] Update rofi-keys manpage with unset section
  * Add format option to disable padding with space the
    "window-format" entries
  * [Script] Split mode string only once on :, allowing : in right
    part.
  * [window] Check bitmask, not full comparison
  * Use command -v instead of which
  * [Keyb] Add a -list-keybindings command.
  * Fix sed binary call with variable
  * [listview] Add extra checks before resolving pointer.
  * [Textbox] Add 'placeholder-markup' flag.
  * [Test][Theme] Update test for downgrade error
  * [Theme] If no theme loaded, load default. Downgrade missing
    theme file to warning.
  * [DMenu] reset variable correctly so keep-selection is initially
    off.
  * Update test for # keybindings.
  * [View|Xcb] Add support to copy current selected item to
    clipboard
  * Include sys/stat.h for S_IWUSR
  * [View] Tweak error message and instant/delayed switching.
  * [View] Change refilter timeout limit to be in time units (ms)
  * [Combi] Fix possible memory leak.
  * [combi] Fix selecting entry with only bang as input.
  * [View] Increase default refilter-timeout-limit.
* Tue Mar  5 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.7.5+wayland3+git.1709656676.1c41373:
  * Set -dev version
  * Bump to 1.7.5+wayland3
  * [Doc] Fix -global-kb docs
  * [WaylandWindow] Remove a scary log
  * [Wayland] Fix axis events handling
  * [Wayland] Fix last missing non-strict prototype
  * [Config] Rename global-kbindings to global-kb
  * [Build] Fix deprecated format() in meson.build
  * [Wayland] Make bindings inhibitor opt-in
  * [Wayland] Update layer shell protocol
  * [Wayland] Inhibit compositor shortcuts
  * [Wayland] Fix implicit deps in view-internal.h
  * [Wayland] Fix remaining non-strict C prototypes
  * [WaylandWindow] Fix missing escaping
  * [WaylandWindow] Unmap surface before sending activation request
  * Document ebuild for Gentoo in GURU
  * [Wayland] Compositor-side cursors via cursor-shape-v1
  * [Wayland] Cursor types support
  * [Wayland] Clear `frame_cb` after destroying resources
  * Re-indent Wayland sources with clang-format
  * [Wayland] Fix crash during layer shell destruction
  * [Doc] Update wayland limitations list
  * [Wayland] Implement `config.dpi` support.
  * [Wayland] Support -m/-monitor <name>.
  * [Wayland] Print monitor layout
  * [Wayland] Support wl_output version 4.
  * [Window] Set mode type for Wayland implementation.
  * Restrict WM detection to XCB backend
  * Enable pango markup for -window-format in wayland
  * [IconFetcher] Re-introduce icon scaling on wayland
  * Revert "[IconFetcher] Apply scaling when loading images and icons"
  * hover select
* Sat Nov 25 2023 mcepl@cepl.eu
- Update to version 1.7.5+wayland2+git.1697052256.5cd1e3c:
  * Pass the xkb `group` (a.k.a. `layout`) to `nk_bindings`
  * [Doc] Fix github issue templates
  * [CI] Better test xcb and wayland-only builds
  * Doc: Clarify issue template and CONTRIBUTING
  * Wayland: fix wayland-only mode again
  * [View|Textbox] cleanups to drawing code
  * Clip text with extents rectangle
  * [Rofi] Expand cache-dir
  * Fix typos in dmenu docs (#1891)
  * Support single quotes for strings as in CSS
  * [Theme] Fix missing doxygen documentation
  * [Theme] Fix opening abs path if no/wrong extension (backward comp.)
  * [rofi-theme] fix typo
  * [Theme] Try to fix importing of theme.
  * script: Let script handle empty custom input
  * widget_draw: clean useless calls in corner drawing
  * Fix border segments stitch
  * Fix mm type in description
  * Remaining modi words in the code
  * Better descriptions for sort options group
  * update man pages without scripts
  * [Lexer] Print some more debug info on error.
  * [Script] Set type on Mode object.
  * [window] Quick test of code scanning.
  * Add CodeQL workflow (#1863)
  * Remove unused variable.
  * [ROFI] -e '-' reads from stdin
  * [ConfigParser] Don't pass commandline options with very long args.
  * [Build] Fix autotools build system.
  * [Doc] Fix some missing/wrong doxygen headers.
  * Print window manager in -help output
  * Merging in the Recursive file browser.
  * Add wezterm to rofi-sensible-terminal (#1838)
  * [DRun] Add option to scan desktop directory for desktop files.
  * gitmodules: Update libnkutils
  * [IconFetcher] Fix small memory leak.
  * Small memory leaks fixed and other cleanups.
  * [MKDocs] Move logo to top.
  * [MKDocs] Add logo
  * [DMenu] Fix row initial tab if non-first column is shown first.
  * [Doc] Update theme manpage with remark-lint hints.
  * [Doc] More small markdown fixes.
  * [DOC] Update rofi-script update with remark-lint remarks.
  * Remove unneeded test and extra enforcement of 0 terminated buffer
  * [Doc] Update rofi.1.markdown with markdown fixes.
  * [DOC] update readme.md with remark-lint updates..
  * [DOC] Update INSTALL,md with remark-lint fixes.
  * [DOC] Add some remark markdown fixes.
  * Fix to pointless or's.
  * [UnitTest] Add more tests for environment parsing.
  * [Doc] Mention location of scripts in manpage.
  * Re-indent the code using clang-format
  * Fix typo in template.
  * Update issue template to include checkbox for version.
  * [Doc] Re-generate manpage
  * docs: element children theming (#1818)
  * Add support for adding textbox widgets to listview elements (#1792)
  * [Textbox] cairo_save/restore does not store path.
  * More Unicode normalization with `-normalize-match` (#1813)
  * #1802: Calc broken fix (#1803)
  * [Dmenu] Small fix that disabled async mode when multi-select is enabled.
  * [View] Fix wrong bitmask checking. (& not |)
  * [rofi-theme-selector] prepend newline before specifying new theme (#1791)
  * [MKDocs] Try to fix link.
  * [MKDocs] Add downloads to side menu
  * [MKDocs] Add a download page.
  * [Script] Strip pango markup when matching rows (#1795)
  * [Doc] theme, spelling fix and more textual tweaks.
  * [Doc] More tweaks to get the formulation right.
  * [Doc] themes manpage, small textual improvement.
  * [Doc] Try to fix some markdown, themes.
  * [Doc] Try to clarify the children situation for the listview widget.
  * [EntryHistory] Disable entry history when dmenu password is set.
  * I785 (#1789)
  * [doc] Add conflicting constraint section to manpage.
  * [mkdoc] add link to user scripts
  * [Textbox] Replace 'space' with a space
  * draw text after cursor (#1777)
  * [Doc] Small tweak to markdown.
  * [Example] Small change in escaping for caday.
  * Update copyright dates.
  * [Doc] Add manpage documentation for pango font string.
  * [MKDocs] Add dynamic theme guide.
  * [FileBrowser] Allow command to be overwritten
  * [theme] Small theme tweak.
  * [Theme] Add NO_IMAGE mode to theme.
  * [Themes] add fullscreen theme with preview part.
  * [window] When no window title set, handle this more gracefully
  * [DMenu|Script] Add per row urgent/active option.
  * sed & realpath workaround for BSD and Darwin OS
  * [filebrowser] Add option to return 1 on cancel.
  * [Theme] Small tweak to fancy2 theme
  * update issue template
  * update issue template
  * update issue template
  * update issue template with check
  * [MKDocs] Link to rasi files in theme page.
  * [Themes] Add fancy2 theme.
  * [Themes] Add material theme
  * Fix header theme
  * [Helper] Quick fix for wrong dereference.
  * MKDoc website (#1772)
  * [themes] don't use screenshot transparency in shipped themes
  * [IconFetcher] Fix for api change
  * [Theme] support rasinc for theme include files.
  * [listview] Don't calculate infinite rows on empty height.
  * [CI] Maintenance. (#1767)
  * [Theme] Move some definitions header around for plugin.
  * [Textbox] Cursor goes over, not under. allow cursor outline.
  * [Textbox] Add text-outline to style
  * [Doc] Clarify documentation on `require-input` further.
  * [Doc] Clarify that `require-input` only hides it.
  * make cursor more customizable by adding cursor-width and cursor-color (#1753)
  * [XIM] Fix an unitialized value problem.
  * [Doc] Add example run command with cgroup support (#1752)
  * [Build] Fix test building in makefile.
  * [Doc] Add documentation for new functions.
  * [Doc] Fix some missing docu.
  * [DMenu] Add -ellipsize-mode option.
  * Move config.h
  * Move doxy-coverage to davatorium version
  * [listview] Set ellipsize mode on creation of textbox
  * Disable imdkit by default
  * Build documentation (#1744)
  * [Build] Use built-in lto option.
  * [Window] Fix reloading windowcd from xserver request
  * [Build]  Add option to build with lto to meson.
  * [Build] Add option to disable imdkit at compile time.
  * [Doc] Update support links.
  * input method (#1735)
  * [Window] Make sure their is a trailing 0 on the workspace strings.
  * [FileBrowser] Bind kb-delete-entry to toggle show-hidden.
  * [Textbox] Add a 'get_cursor_x_pos' function.
  * [man] re-gen manpage.
  * [DOC] Add parsing row options to dmenu manpage (#1734)
  * [Build] Fix icon install path for makefile.
  * [Window] Small fixes to prefer-icon-theme option
  * [Window] Add -window-prefer-icon-theme option.
  * [drun] Only pass path on launch, if one is set
  * The mode is filebrowser (not file-browser) (#1723)
  * [DOC] Rerun update-manpages.
  * [filebrowser] Add an option to show hidden files. (#1716)
  * gitmodules: fix submodule again.
  * [Doc] Update rofi-keys manpage with unset section
* Sat Nov 25 2023 Matej Cepl <mcepl@cepl.eu>
- Remove
  Use-xdg-terminal-instead-of-the-proprietary-solution.patch, it
  is evil (gh#davatorium/rofi#355).
* Mon Jul 24 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.7.5+wayland2+git.1690115482.ff2338c:
  * Set -dev version
  * Wayland: Apply scaling to cursor surface
  * [IconFetcher] Apply scaling when loading images and icons
- Update service file to use wayland2 naming and obs_scm
* Tue May 30 2023 mcepl@suse.com
- Update to version 1.7.5+wayland1+git.1679493688.d06095b:
  * Propose new PRs to go the 'wayland' branch, not the upstream one.
  * Add information about the openSUSE package
  * [Doc] remove some links to upstream rofi
  * Wayland: fix NULL pointer access
  * Wayland: real fullscreen support
  * Fix redraw bug when changing window height
  * [Doc] Update on window mode in README
  * [Doc] Update Fedora package link.
  * [WaylandWindow] Remove redundant icon fetcher query.
  * [WaylandWindow] Apply changes from b3c46d2:
* Sat Nov  5 2022 Matej Cepl <mcepl@suse.com>
- rofi-wayland-devel should conflict rofi-devel.
* Mon Oct 31 2022 Matej Cepl <mcepl@suse.com>
- Switch back from SCM managed to plain old OBS package.
- Update to 1.7.5+wayland1:
  - just following the upstream
    (https://github.com/davatorium/rofi) changes.
- Add rofi-launcher provides to allow coexistence with
  rofi-wayland.
* Sat Aug 20 2022 Matej Cepl <mcepl@suse.com>
- Rename package to rofi-wayland and conflict with the original one.
- Make the package Wayland only.
- Switch to Sourcehut upstream repo with my patches
  (https://git.sr.ht/~mcepl/rofi)
* Sat Aug  6 2022 Matej Cepl <mcepl@suse.com>
- Conversion of the original project from
  https://build.opensuse.org/package/show/home:h3o/Rofi-Wayland
  (with updated build to have working submodules).
